<?php
//
// This module reads and prints exif details from current image
// if image details bar is not displayed (by Show Details button).
//
// Feel free to add, remove and rearrange parameters.
//
if ($image->IsImage() && // This will protect against direct include
    !($bShowDetails && $g_bShowEXIFDetailsButton))
{
    // Read EXIF
    if ($g_bForceDAlbumEXIFCode || !extension_loaded('exif'))
    {
        require_once(DALBUM_ROOT  . "/include/exif.php");
        $exif=@exif_php_read_data(absfname($image->m_sFullFilename));
    }
    else
    {
        $exif=@exif_read_data(absfname($image->m_sFullFilename));
    }

//              print "<PRE>";
//        print_r($exif);
//        die();



    if ($exif===false)
        $exif=array();

    $data=array();

    // Resolution
    if ($image->m_nX>0 && $image->m_nY>0)
        $data[]="|({$image->m_nX}x{$image->m_nY})";

    // Date/time
    $date="";
    if (isset($exif['DateTimeOriginal']))
        $date=$exif['DateTimeOriginal'];
    if (empty($date) && isset($exif['DateTime']))
        $date=$exif['DateTime'];

    if (!empty($date))
    {
        $date=split(':',str_replace(' ',':',$date));
        $date="{$date[0]}-{$date[1]}-{$date[2]} {$date[3]}:{$date[4]}:{$date[5]}";
        $date=strftime($lang['cExiflineDateFormat'],strtotime($date));
        $data[]="|$date";
    }

    // ISO speed
    $iso="";

    if (isset($exif['ISOSpeedRatings']))
        $iso=$exif['ISOSpeedRatings'];
    else if (isset($exif['MakerNote']) && isset($exif['ModeArray']))
    {
        // Add ISO for PowerShot cameras
        switch (@$exif['ModeArray'][16])
        {
            case 15: $iso="auto";break;
            case 16: $iso="50";break;
            case 17: $iso="100";break;
            case 18: $iso="200";break;
            case 19: $iso="400";break;
        }
    }

    if (!empty($iso))
        $data[]="{$lang['showExifISO']}|$iso";

    if (isset($exif['FocalLength']))
    {
        list($d1,$d2)=split('/',$exif['FocalLength']);
        if ($d1>0 && $d2>0)
        {
            $e=round($d1/$d2,1);
            $data[]="{$lang['cExiflineFocal']}|$e mm";
        }
    }


    // Exposure
    $shutter=0;
    if (isset($exif['ExposureTime']))
    {
        list($d1,$d2)=split('/',$exif['ExposureTime']);
        if ($d1>0 && $d2>0)
            $shutter=$d1/$d2;
        else
            $shutter=$exif['ExposureTime'];

        if ($shutter<1 && $shutter>0)
            $e="1/" . round(1/$shutter,0) . " s";
        else
            $e=round($shutter,1) ." s";

        $data[]=$lang['cExiflineExposure']."|".$e;
    }

    // Aperture
    if (isset($exif['COMPUTED']['ApertureFNumber']))
    {
        $data[]="{$lang['cExiflineAperture']}|{$exif['COMPUTED']['ApertureFNumber']}";
    }


    // Flash
    if (isset($exif['Flash']))
    {
        $e=$lang[($exif['Flash']&1)?'showExifFlashYes':'showExifFlashNo'];
        $data[]="{$lang['cExiflineFlash']}$e";
    }

    // Combine all together into one line
    $sExifDetails="";
    if (!empty($data))
    {
        foreach ($data as $d)
        {
            $arr=split('\|',$d);
            if (count($arr)==2)
            {
                if (!empty($sExifDetails))
                    $sExifDetails.="; ";
                $sExifDetails.="{$arr[0]}{$arr[1]}";
            }
        }
    }

    // print the line
    print $sExifDetails;
}

function CanonEv($val)
{
    // temporarily make the number positive
    $sign = 1;
    if ($val < 0)
    {
        $val = -$val;
        $sign = -1;
    }
    $frac = $val & 0x1f;
    $val -= $frac;      // remove fraction
    // Convert 1/3 and 2/3 codes
    if ($frac == 0x0c)
    {
        $frac = 0x20 / 3;
    } elseif ($frac == 0x14)
    {
        $frac = 0x40 / 3;
    }
    return $sign * ($val + $frac) / 0x20;
}
?>